@@ -1,18 +1,20 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" sourcelanguage="en_US" language="nl">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="nl" sourcelanguage="en_US">
 <context>
     <name>ManualProxy</name>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="322"/>
+        <location filename="../src/view/manual_proxy.cpp" line="363"/>
         <source>Learn Basic Operations</source>
         <translation>Basishandelingen leren</translation>
     </message>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="324"/>
+        <location filename="../src/view/manual_proxy.cpp" line="366"/>
         <source>Common Application Libraries</source>
         <translation>Veelvoorkomende programmabibliotheken</translation>
     </message>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="326"/>
+        <location filename="../src/view/manual_proxy.cpp" line="369"/>
         <source>Desktop Environment</source>
         <translation>Werkomgeving</translation>
     </message>
@@ -20,94 +22,94 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="291"/>
         <source>Search for &quot;%1&quot; in the full text</source>
         <translation>&apos;%1&apos; zoeken in de hele tekst</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="301"/>
+        <location filename="../src/view/web_window.cpp" line="363"/>
         <source>The content was updated</source>
         <translation>De inhoud is bijgewerkt</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="624"/>
+        <location filename="../src/view/web_window.cpp" line="767"/>
         <source>Search</source>
         <translation>Zoeken</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="627"/>
-        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
+        <location filename="../src/view/web_window.cpp" line="771"/>
         <source>Support</source>
         <translation>Ondersteuning</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="836"/>
+        <location filename="../src/view/web_window.cpp" line="1038"/>
         <source>Copy</source>
         <translation>Kopiëren</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
         <source>Quick Start</source>
         <translation>Snelstartgids</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
         <source>Video Guide</source>
         <translation>Videogids</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="23"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
         <source>System</source>
         <translation>Systeem</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="24"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
         <source>Applications</source>
         <translation>Programma&apos;s</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
         <source>No search results</source>
         <translation>Geen zoekresultaten</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
         <source>Home</source>
         <translation>Start</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
         <source>  result</source>
         <translation>  resultaat</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
         <source>  results</source>
         <translation>  resultaten</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
         <source>Click to view </source>
         <translation>Klik om te bekijken</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
         <source>View all</source>
         <translation>Alles bekijken</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
         <source>App Store</source>
         <translation>Appwinkel</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="105"/>
+        <location filename="../src/app/dman.cpp" line="136"/>
         <source>Manual</source>
         <translation>Handleiding</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="106"/>
+        <location filename="../src/app/dman.cpp" line="137"/>
         <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
         <translation>Handleiding is ontworpen om gebruikers te helpen met het besturingssysteem en de programma&apos;s. Het bevat instructies en functie-omschrijvingen, zodat gebruikers het systeem kunnen leren gebruiken.</translation>
     </message>
@@ -115,14 +117,14 @@
 <context>
     <name>WebWindow</name>
     <message>
-        <location filename="../src/view/web_window.cpp" line="765"/>
+        <location filename="../src/view/web_window.cpp" line="952"/>
         <source>Ctrl+Alt+F</source>
         <translation>Ctrl+Alt+F</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="780"/>
+        <location filename="../src/view/web_window.cpp" line="969"/>
         <source>Ctrl+F</source>
         <translation>Ctrl+F</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
